@@ -100,10 +100,11 @@ def callback(out_func, system_stats, system_kwargs, user_kwargs, ret):
     utils.handle_return_common(out_func, ret, system_stats, system_kwargs, user_kwargs)
 
 
-def error_callback(e):
-    # not sure I have ever seen this called
+def error_callback(out_func, system_stats, system_kwargs, user_kwargs, e):
+    system_kwargs['outstanding'] -= 1
     print('error_callback, exception is', repr(e), file=sys.stderr)
-    raise ValueError('error_callback, exception is '+repr(e))
+    # do not raise here, it causes a hang
+    # we do not know the pset, so we cannot fake a return value
 
 
 def progress_until_fewer(cores, factor, out_func, system_stats, system_kwargs, user_kwargs, group_size):
@@ -119,7 +120,7 @@ def progress_until_fewer(cores, factor, out_func, system_stats, system_kwargs, u
     return group_size
 
 
-def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=None, outfile=None, out_subdirs=None,
+def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=None, out_subdirs=None,
         progress_dt=None, group_size=None, name='default', **kwargs):
 
     verbose = system_kwargs['verbose']
@@ -128,7 +129,7 @@ def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=
     if utils.psets_empty(psets):
         return
 
-    psets, system_stats, system_kwargs = utils.map_prep(psets, name, system_kwargs, chdir, outfile,
+    psets, system_stats, system_kwargs = utils.map_prep(psets, name, system_kwargs, chdir,
                                                         out_subdirs, progress_dt=progress_dt, **kwargs)
 
     progress = system_kwargs['progress']
