@@ -161,7 +161,7 @@ def progress_until_fewer(futures, cores, factor, out_func, system_stats, system_
 
         if len(done):
             if verbose and len(done) > 100:  # pragma: no cover
-                print('surprised to see {} psets done at once'.format(len(done)), file=sys.stderr)
+                print('surprised to see {} pset groups done at once'.format(len(done)), file=sys.stderr)
                 sys.stderr.flush()
             for ret in done:
                 handle_return(out_func, ret, system_stats, system_kwargs, user_kwargs)
@@ -178,7 +178,7 @@ def progress_until_fewer(futures, cores, factor, out_func, system_stats, system_
     return futures, cores, group_size
 
 
-def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=None, outfile=None, out_subdirs=None,
+def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=None, out_subdirs=None,
         progress_dt=None, group_size=None, name='default', **kwargs):
 
     verbose = system_kwargs['verbose']
@@ -187,7 +187,7 @@ def map(func, psets, out_func=None, system_kwargs=None, user_kwargs=None, chdir=
     if utils.psets_empty(psets):
         return
 
-    psets, system_stats, system_kwargs = utils.map_prep(psets, name, system_kwargs, chdir, outfile,
+    psets, system_stats, system_kwargs = utils.map_prep(psets, name, system_kwargs, chdir,
                                                         out_subdirs, progress_dt=progress_dt, **kwargs)
     if 'chdir' not in system_kwargs:
         # ray workers default to ~
