@@ -1,7 +1,5 @@
 import time
 import sys
-import math
-import random
 from contextlib import contextmanager
 from collections import defaultdict
 
@@ -10,11 +8,23 @@ from hdrh.iterators import LinearIterator
 
 
 class PerfStats(object):
-    def __init__(self, raw_stats=None):
+    def __init__(self, raw_stats=None, vstats=1):
         self.d = dict()
+        self.stats_last = time.time()
+        self.stats_dt = self.pick_dt(vstats)
+        self.stats_log_last = time.time()
+        self.stats_log_dt = 30  # hardwired
         if raw_stats:
             self.combine_stats(raw_stats)
 
+    def pick_dt(self, vstats):
+        if vstats > 1:
+            return 1
+        elif vstats == 1:
+            return 30
+        else:
+            return 1000000
+
     def combine_stats(self, raw_stats):
         for name, elapsed in raw_stats.items():
             g = self.d.get(name, defaultdict(float))
@@ -37,10 +47,14 @@ class PerfStats(object):
     def all_stat_names(self):
         return self.d.keys()
 
-    def bingo(self):
-        # print percentiles 1/100 of the time
-        if random.randint(0, 99) == 0:
+    def report(self, vstats, final=False, other_fd=None):
+        t = time.time()
+        if final or t - self.stats_last > self.stats_dt:
+            self.stats_last = t
             self.print_percentiles()
+        if other_fd and (final or t - self.stats_log_last > self.stats_log_dt):
+            self.stats_log_last = t
+            self.print_percentiles(file=other_fd)
 
     def print_percentiles(self, name='default', file=sys.stdout):
         self.print_percentile(name, file=file)
